@@ -1,4 +1,5 @@
 import json
+
 import moto.server as server
 
 
@@ -44,17 +45,17 @@ def test_sign_up_user_without_authentication():
             "Authorization": "AWS4-HMAC-SHA256 Credential=abcd/20010101/us-east-2/s3/aws4_request, SignedHeaders=host;x-amz-content-sha256;x-amz-date, Signature=...",
         },
     )
-    json.loads(res.data)["UserPoolClients"].should.have.length_of(1)
+    assert len(json.loads(res.data)["UserPoolClients"]) == 1
 
     # Sign Up User
-    data = {"ClientId": client_id, "Username": "test@gmail.com", "Password": "12345678"}
+    data = {"ClientId": client_id, "Username": "test@gmail.com", "Password": "P2$Sword"}
     res = test_client.post(
         "/",
         data=json.dumps(data),
         headers={"X-Amz-Target": "AWSCognitoIdentityProviderService.SignUp"},
     )
-    res.status_code.should.equal(200)
-    json.loads(res.data).should.have.key("UserConfirmed").equals(False)
+    assert res.status_code == 200
+    assert json.loads(res.data)["UserConfirmed"] is False
 
     # Confirm Sign Up User
     data = {
@@ -72,14 +73,14 @@ def test_sign_up_user_without_authentication():
     data = {
         "ClientId": client_id,
         "AuthFlow": "USER_PASSWORD_AUTH",
-        "AuthParameters": {"USERNAME": "test@gmail.com", "PASSWORD": "12345678"},
+        "AuthParameters": {"USERNAME": "test@gmail.com", "PASSWORD": "P2$Sword"},
     }
     res = test_client.post(
         "/",
         data=json.dumps(data),
         headers={"X-Amz-Target": "AWSCognitoIdentityProviderService.InitiateAuth"},
     )
-    res.status_code.should.equal(200)
+    assert res.status_code == 200
     access_token = json.loads(res.data)["AuthenticationResult"]["AccessToken"]
 
     # Get User
@@ -89,11 +90,11 @@ def test_sign_up_user_without_authentication():
         data=json.dumps(data),
         headers={"X-Amz-Target": "AWSCognitoIdentityProviderService.GetUser"},
     )
-    res.status_code.should.equal(200)
+    assert res.status_code == 200
     data = json.loads(res.data)
-    data.should.have.key("UserPoolId").equals(user_pool_id)
-    data.should.have.key("Username").equals("test@gmail.com")
-    data.should.have.key("UserStatus").equals("CONFIRMED")
+    assert data["UserPoolId"] == user_pool_id
+    assert data["Username"] == "test@gmail.com"
+    assert data["UserStatus"] == "CONFIRMED"
 
 
 def test_admin_create_user_without_authentication():
@@ -132,7 +133,7 @@ def test_admin_create_user_without_authentication():
     data = {
         "UserPoolId": user_pool_id,
         "Username": "test@gmail.com",
-        "TemporaryPassword": "12345678",
+        "TemporaryPassword": "A!1a12345678",
     }
     res = test_client.post(
         "/",
@@ -142,13 +143,13 @@ def test_admin_create_user_without_authentication():
             "Authorization": "AWS4-HMAC-SHA256 Credential=abcd/20010101/us-east-2/s3/aws4_request, SignedHeaders=host;x-amz-content-sha256;x-amz-date, Signature=...",
         },
     )
-    res.status_code.should.equal(200)
+    assert res.status_code == 200
 
     # Initiate Auth
     data = {
         "ClientId": client_id,
         "AuthFlow": "USER_PASSWORD_AUTH",
-        "AuthParameters": {"USERNAME": "test@gmail.com", "PASSWORD": "12345678"},
+        "AuthParameters": {"USERNAME": "test@gmail.com", "PASSWORD": "A!1a12345678"},
     }
     res = test_client.post(
         "/",
@@ -163,7 +164,7 @@ def test_admin_create_user_without_authentication():
         "ChallengeName": "NEW_PASSWORD_REQUIRED",
         "ChallengeResponses": {
             "USERNAME": "test@gmail.com",
-            "NEW_PASSWORD": "abcdefgh",
+            "NEW_PASSWORD": "A!1aabcdefgh",
         },
         "Session": session,
     }
@@ -174,9 +175,100 @@ def test_admin_create_user_without_authentication():
             "X-Amz-Target": "AWSCognitoIdentityProviderService.RespondToAuthChallenge"
         },
     )
-    res.status_code.should.equal(200)
+    assert res.status_code == 200
     response = json.loads(res.data)
 
-    response.should.have.key("AuthenticationResult")
-    response["AuthenticationResult"].should.have.key("IdToken")
-    response["AuthenticationResult"].should.have.key("AccessToken")
+    assert "AuthenticationResult" in response
+    assert "IdToken" in response["AuthenticationResult"]
+    assert "AccessToken" in response["AuthenticationResult"]
+
+
+def test_associate_software_token():
+    backend = server.create_backend_app("cognito-idp")
+    test_client = backend.test_client()
+
+    # Create User Pool
+    res = test_client.post(
+        "/",
+        data='{"PoolName": "test-pool"}',
+        headers={
+            "X-Amz-Target": "AWSCognitoIdentityProviderService.CreateUserPool",
+            "Authorization": "AWS4-HMAC-SHA256 Credential=abcd/20010101/us-east-2/s3/aws4_request, SignedHeaders=host;x-amz-content-sha256;x-amz-date, Signature=...",
+        },
+    )
+    user_pool_id = json.loads(res.data)["UserPool"]["Id"]
+
+    # Create User Pool Client
+    data = {
+        "UserPoolId": user_pool_id,
+        "ClientName": "some-client",
+        "GenerateSecret": False,
+        "ExplicitAuthFlows": ["ALLOW_USER_PASSWORD_AUTH"],
+    }
+    res = test_client.post(
+        "/",
+        data=json.dumps(data),
+        headers={
+            "X-Amz-Target": "AWSCognitoIdentityProviderService.CreateUserPoolClient",
+            "Authorization": "AWS4-HMAC-SHA256 Credential=abcd/20010101/us-east-2/s3/aws4_request, SignedHeaders=host;x-amz-content-sha256;x-amz-date, Signature=...",
+        },
+    )
+    client_id = json.loads(res.data)["UserPoolClient"]["ClientId"]
+
+    # Sign Up User
+    data = {
+        "ClientId": client_id,
+        "Username": "user_2_mfa",
+        "Password": "12312sdfasASDFDSF$",
+    }
+    res = test_client.post(
+        "/",
+        data=json.dumps(data),
+        headers={"X-Amz-Target": "AWSCognitoIdentityProviderService.SignUp"},
+    )
+    assert res.status_code == 200
+    assert json.loads(res.data)["UserConfirmed"] is False
+
+    # Confirm Sign Up User
+    data = {"ClientId": client_id, "Username": "user_2_mfa", "ConfirmationCode": "sth"}
+    res = test_client.post(
+        "/",
+        data=json.dumps(data),
+        headers={"X-Amz-Target": "AWSCognitoIdentityProviderService.ConfirmSignUp"},
+    )
+
+    # Initiate Auth
+    data = {
+        "AuthFlow": "USER_PASSWORD_AUTH",
+        "AuthParameters": {
+            "USERNAME": "user_2_mfa",
+            "PASSWORD": "12312sdfasASDFDSF$",
+            "SECRET_HASH": "kIWuIv6ElVe9ahZHJ+gqvZe6CgEkVE/BjQmJcMSgF3E=",
+        },
+        "ClientId": client_id,
+    }
+    res = test_client.post(
+        "/",
+        data=json.dumps(data),
+        headers={"X-Amz-Target": "AWSCognitoIdentityProviderService.InitiateAuth"},
+    )
+    auth_data = json.loads(res.data.decode("utf-8"))["AuthenticationResult"]
+
+    # Get User
+    data = {"AccessToken": auth_data["AccessToken"]}
+    res = test_client.post(
+        "/",
+        data=json.dumps(data),
+        headers={"X-Amz-Target": "AWSCognitoIdentityProviderService.GetUser"},
+    )
+
+    # Associate Software Token
+    data = {"AccessToken": auth_data["AccessToken"]}
+    res = test_client.post(
+        "/",
+        data=json.dumps(data),
+        headers={
+            "X-Amz-Target": "AWSCognitoIdentityProviderService.AssociateSoftwareToken"
+        },
+    )
+    assert json.loads(res.data.decode("utf-8")) == {"SecretCode": "asdfasdfasdf"}
