@@ -2,10 +2,10 @@ import boto3
 import pytest
 from botocore.exceptions import ClientError
 
-from moto import mock_guardduty
+from moto import mock_aws
 
 
-@mock_guardduty
+@mock_aws
 def test_create_detector():
     client = boto3.client("guardduty", region_name="us-east-1")
     response = client.create_detector(
@@ -13,13 +13,14 @@ def test_create_detector():
         ClientToken="745645734574758463758",
         FindingPublishingFrequency="ONE_HOUR",
         DataSources={"S3Logs": {"Enable": True}},
+        Features=[{"Name": "Test", "Status": "ENABLED"}],
         Tags={},
     )
     assert "DetectorId" in response
     assert response["DetectorId"] is not None
 
 
-@mock_guardduty
+@mock_aws
 def test_create_detector_with_minimal_params():
     client = boto3.client("guardduty", region_name="us-east-1")
     response = client.create_detector(Enable=True)
@@ -27,7 +28,7 @@ def test_create_detector_with_minimal_params():
     assert response["DetectorId"] is not None
 
 
-@mock_guardduty
+@mock_aws
 def test_get_detector_with_s3():
     client = boto3.client("guardduty", region_name="us-east-1")
     detector_id = client.create_detector(
@@ -44,7 +45,7 @@ def test_get_detector_with_s3():
     assert "CreatedAt" in resp
 
 
-@mock_guardduty
+@mock_aws
 def test_get_detector_with_all_data_sources():
     client = boto3.client("guardduty", region_name="us-east-1")
     detector_id = client.create_detector(
@@ -65,7 +66,36 @@ def test_get_detector_with_all_data_sources():
     assert "CreatedAt" in resp
 
 
-@mock_guardduty
+@mock_aws
+def test_get_detector_with_features():
+    client = boto3.client("guardduty", region_name="us-east-1")
+    detector_id = client.create_detector(
+        Enable=True,
+        Features=[
+            {
+                "Name": "EKS_AUDIT_LOGS",
+                "Status": "ENABLED",
+                "AdditionalConfiguration": [
+                    {"Name": "EKS_ADDON_MANAGEMENT", "Status": "ENABLED"}
+                ],
+            },
+            {"Name": "TS3_DATA_EVENTS", "Status": "DISABLED"},
+        ],
+    )["DetectorId"]
+
+    resp = client.get_detector(DetectorId=detector_id)
+    assert len(resp["Features"]) == 2
+    assert resp["Features"][0]["Name"] == "EKS_AUDIT_LOGS"
+    assert resp["Features"][0]["Status"] == "ENABLED"
+    assert (
+        resp["Features"][0]["AdditionalConfiguration"][0]["Name"]
+        == "EKS_ADDON_MANAGEMENT"
+    )
+    assert resp["Features"][1]["Name"] == "TS3_DATA_EVENTS"
+    assert resp["Features"][1]["Status"] == "DISABLED"
+
+
+@mock_aws
 def test_update_detector():
     client = boto3.client("guardduty", region_name="us-east-1")
     detector_id = client.create_detector(
@@ -83,15 +113,17 @@ def test_update_detector():
             "S3Logs": {"Enable": True},
             "Kubernetes": {"AuditLogs": {"Enable": False}},
         },
+        Features=[{"Name": "Test", "Status": "ENABLED"}],
     )
 
     resp = client.get_detector(DetectorId=detector_id)
     assert resp["FindingPublishingFrequency"] == "SIX_HOURS"
     assert resp["DataSources"]["S3Logs"] == {"Status": "ENABLED"}
     assert resp["DataSources"]["Kubernetes"]["AuditLogs"] == {"Status": "DISABLED"}
+    assert resp["Features"] == [{"Name": "Test", "Status": "ENABLED"}]
 
 
-@mock_guardduty
+@mock_aws
 def test_list_detectors_initial():
     client = boto3.client("guardduty", region_name="us-east-1")
 
@@ -99,7 +131,7 @@ def test_list_detectors_initial():
     assert response["DetectorIds"] == []
 
 
-@mock_guardduty
+@mock_aws
 def test_list_detectors():
     client = boto3.client("guardduty", region_name="us-east-1")
     d1 = client.create_detector(
@@ -115,7 +147,7 @@ def test_list_detectors():
     assert set(response["DetectorIds"]) == {d1, d2}
 
 
-@mock_guardduty
+@mock_aws
 def test_delete_detector():
     client = boto3.client("guardduty", region_name="us-east-1")
     detector_id = client.create_detector(
