@@ -1,14 +1,16 @@
 import json
 from datetime import timedelta
+from uuid import uuid4
 
 import boto3
 import pytest
 from botocore.exceptions import ClientError
 from freezegun import freeze_time
 
-from moto import mock_logs, settings
+from moto import mock_aws, settings
 from moto.core.utils import unix_time_millis, utcnow
 from moto.logs.models import MAX_RESOURCE_POLICIES_PER_REGION
+from tests import allow_aws_request, aws_verified
 
 TEST_REGION = "us-east-1" if settings.TEST_SERVER_MODE else "us-west-2"
 
@@ -47,228 +49,24 @@ access_policy_doc = json.dumps(
 )
 
 
-@mock_logs
-def test_describe_metric_filters_happy_prefix():
-    conn = boto3.client("logs", "us-west-2")
-
-    response1 = put_metric_filter(conn, count=1)
-    assert response1["ResponseMetadata"]["HTTPStatusCode"] == 200
-    response2 = put_metric_filter(conn, count=2)
-    assert response2["ResponseMetadata"]["HTTPStatusCode"] == 200
-
-    response = conn.describe_metric_filters(filterNamePrefix="filter")
-
-    assert len(response["metricFilters"]) == 2
-    assert response["metricFilters"][0]["filterName"] == "filterName1"
-    assert response["metricFilters"][1]["filterName"] == "filterName2"
+@pytest.fixture(name="log_group_name")
+def create_log_group():
+    if allow_aws_request():
+        yield from _create_log_group()
+    else:
+        with mock_aws():
+            yield from _create_log_group()
 
 
-@mock_logs
-def test_describe_metric_filters_happy_log_group_name():
-    conn = boto3.client("logs", "us-west-2")
-
-    response1 = put_metric_filter(conn, count=1)
-    assert response1["ResponseMetadata"]["HTTPStatusCode"] == 200
-    response2 = put_metric_filter(conn, count=2)
-    assert response2["ResponseMetadata"]["HTTPStatusCode"] == 200
-
-    response = conn.describe_metric_filters(logGroupName="logGroupName2")
-
-    assert len(response["metricFilters"]) == 1
-    assert response["metricFilters"][0]["logGroupName"] == "logGroupName2"
+def _create_log_group():
+    conn = boto3.client("logs", TEST_REGION)
+    log_group_name = f"test_log_group_{str(uuid4())[0:6]}"
+    conn.create_log_group(logGroupName=log_group_name)
+    yield log_group_name
+    conn.delete_log_group(logGroupName=log_group_name)
 
 
-@mock_logs
-def test_describe_metric_filters_happy_metric_name():
-    conn = boto3.client("logs", "us-west-2")
-
-    response1 = put_metric_filter(conn, count=1)
-    assert response1["ResponseMetadata"]["HTTPStatusCode"] == 200
-    response2 = put_metric_filter(conn, count=2)
-    assert response2["ResponseMetadata"]["HTTPStatusCode"] == 200
-
-    response = conn.describe_metric_filters(
-        metricName="metricName1", metricNamespace="metricNamespace1"
-    )
-
-    assert len(response["metricFilters"]) == 1
-    metrics = response["metricFilters"][0]["metricTransformations"]
-    assert metrics[0]["metricName"] == "metricName1"
-    assert metrics[0]["metricNamespace"] == "metricNamespace1"
-
-
-@mock_logs
-def test_put_metric_filters_validation():
-    conn = boto3.client("logs", "us-west-2")
-
-    invalid_filter_name = "X" * 513
-    invalid_filter_pattern = "X" * 1025
-    invalid_metric_transformations = [
-        {
-            "defaultValue": 1,
-            "metricName": "metricName",
-            "metricNamespace": "metricNamespace",
-            "metricValue": "metricValue",
-        },
-        {
-            "defaultValue": 1,
-            "metricName": "metricName",
-            "metricNamespace": "metricNamespace",
-            "metricValue": "metricValue",
-        },
-    ]
-
-    test_cases = [
-        build_put_case(name="Invalid filter name", filter_name=invalid_filter_name),
-        build_put_case(
-            name="Invalid filter pattern", filter_pattern=invalid_filter_pattern
-        ),
-        build_put_case(
-            name="Invalid filter metric transformations",
-            metric_transformations=invalid_metric_transformations,
-        ),
-    ]
-
-    for test_case in test_cases:
-        with pytest.raises(ClientError) as exc:
-            conn.put_metric_filter(**test_case["input"])
-        response = exc.value.response
-        assert response["ResponseMetadata"]["HTTPStatusCode"] == 400
-        assert response["Error"]["Code"] == "InvalidParameterException"
-
-
-@mock_logs
-def test_describe_metric_filters_validation():
-    conn = boto3.client("logs", "us-west-2")
-
-    length_over_512 = "X" * 513
-    length_over_255 = "X" * 256
-
-    test_cases = [
-        build_describe_case(
-            name="Invalid filter name prefix", filter_name_prefix=length_over_512
-        ),
-        build_describe_case(
-            name="Invalid log group name", log_group_name=length_over_512
-        ),
-        build_describe_case(name="Invalid metric name", metric_name=length_over_255),
-        build_describe_case(
-            name="Invalid metric namespace", metric_namespace=length_over_255
-        ),
-    ]
-
-    for test_case in test_cases:
-        with pytest.raises(ClientError) as exc:
-            conn.describe_metric_filters(**test_case["input"])
-        response = exc.value.response
-        assert response["ResponseMetadata"]["HTTPStatusCode"] == 400
-        assert response["Error"]["Code"] == "InvalidParameterException"
-
-
-@mock_logs
-def test_describe_metric_filters_multiple_happy():
-    conn = boto3.client("logs", "us-west-2")
-
-    response = put_metric_filter(conn, 1)
-    assert response["ResponseMetadata"]["HTTPStatusCode"] == 200
-
-    response = put_metric_filter(conn, 2)
-    assert response["ResponseMetadata"]["HTTPStatusCode"] == 200
-    response = conn.describe_metric_filters(
-        filterNamePrefix="filter", logGroupName="logGroupName1"
-    )
-    assert response["metricFilters"][0]["filterName"] == "filterName1"
-
-    response = conn.describe_metric_filters(filterNamePrefix="filter")
-    assert response["metricFilters"][0]["filterName"] == "filterName1"
-
-    response = conn.describe_metric_filters(logGroupName="logGroupName1")
-    assert response["metricFilters"][0]["filterName"] == "filterName1"
-
-
-@mock_logs
-def test_delete_metric_filter():
-    client = boto3.client("logs", "us-west-2")
-
-    lg_name = "/hello-world/my-cool-endpoint"
-    client.create_log_group(logGroupName=lg_name)
-    client.put_metric_filter(
-        logGroupName=lg_name,
-        filterName="my-cool-filter",
-        filterPattern="{ $.val = * }",
-        metricTransformations=[
-            {
-                "metricName": "my-metric",
-                "metricNamespace": "my-namespace",
-                "metricValue": "$.value",
-            }
-        ],
-    )
-
-    response = client.delete_metric_filter(
-        filterName="filterName", logGroupName=lg_name
-    )
-    assert response["ResponseMetadata"]["HTTPStatusCode"] == 200
-
-    response = client.describe_metric_filters(
-        filterNamePrefix="filter", logGroupName="logGroupName2"
-    )
-    assert response["metricFilters"] == []
-
-
-@mock_logs
-@pytest.mark.parametrize(
-    "filter_name, failing_constraint",
-    [
-        (
-            "X" * 513,
-            "Minimum length of 1. Maximum length of 512.",
-        ),  # filterName too long
-        ("x:x", "Must match pattern"),  # invalid filterName pattern
-    ],
-)
-def test_delete_metric_filter_invalid_filter_name(filter_name, failing_constraint):
-    conn = boto3.client("logs", "us-west-2")
-    with pytest.raises(ClientError) as exc:
-        conn.delete_metric_filter(filterName=filter_name, logGroupName="valid")
-    response = exc.value.response
-    assert response["ResponseMetadata"]["HTTPStatusCode"] == 400
-    assert response["Error"]["Code"] == "InvalidParameterException"
-    assert (
-        f"Value '{filter_name}' at 'filterName' failed to satisfy constraint"
-        in response["Error"]["Message"]
-    )
-    assert failing_constraint in response["Error"]["Message"]
-
-
-@mock_logs
-@pytest.mark.parametrize(
-    "log_group_name, failing_constraint",
-    [
-        (
-            "X" * 513,
-            "Minimum length of 1. Maximum length of 512.",
-        ),  # logGroupName too long
-        ("x!x", "Must match pattern"),  # invalid logGroupName pattern
-    ],
-)
-def test_delete_metric_filter_invalid_log_group_name(
-    log_group_name, failing_constraint
-):
-    conn = boto3.client("logs", "us-west-2")
-    with pytest.raises(ClientError) as exc:
-        conn.delete_metric_filter(filterName="valid", logGroupName=log_group_name)
-    response = exc.value.response
-    assert response["ResponseMetadata"]["HTTPStatusCode"] == 400
-    assert response["Error"]["Code"] == "InvalidParameterException"
-    assert (
-        f"Value '{log_group_name}' at 'logGroupName' failed to satisfy constraint"
-        in response["Error"]["Message"]
-    )
-    assert failing_constraint in response["Error"]["Message"]
-
-
-@mock_logs
+@mock_aws
 def test_destinations():
     conn = boto3.client("logs", "us-west-2")
     destination_name = "test-destination"
@@ -344,85 +142,7 @@ def test_destinations():
     assert response["ResponseMetadata"]["HTTPStatusCode"] == 200
 
 
-def put_metric_filter(conn, count=1):
-    count = str(count)
-    return conn.put_metric_filter(
-        filterName="filterName" + count,
-        filterPattern="filterPattern" + count,
-        logGroupName="logGroupName" + count,
-        metricTransformations=[
-            {
-                "defaultValue": int(count),
-                "metricName": "metricName" + count,
-                "metricNamespace": "metricNamespace" + count,
-                "metricValue": "metricValue" + count,
-            },
-        ],
-    )
-
-
-def build_put_case(
-    name,
-    filter_name="filterName",
-    filter_pattern="filterPattern",
-    log_group_name="logGroupName",
-    metric_transformations=None,
-):
-    return {
-        "name": name,
-        "input": build_put_input(
-            filter_name, filter_pattern, log_group_name, metric_transformations
-        ),
-    }
-
-
-def build_put_input(
-    filter_name, filter_pattern, log_group_name, metric_transformations
-):
-    if metric_transformations is None:
-        metric_transformations = [
-            {
-                "defaultValue": 1,
-                "metricName": "metricName",
-                "metricNamespace": "metricNamespace",
-                "metricValue": "metricValue",
-            },
-        ]
-    return {
-        "filterName": filter_name,
-        "filterPattern": filter_pattern,
-        "logGroupName": log_group_name,
-        "metricTransformations": metric_transformations,
-    }
-
-
-def build_describe_input(
-    filter_name_prefix, log_group_name, metric_name, metric_namespace
-):
-    return {
-        "filterNamePrefix": filter_name_prefix,
-        "logGroupName": log_group_name,
-        "metricName": metric_name,
-        "metricNamespace": metric_namespace,
-    }
-
-
-def build_describe_case(
-    name,
-    filter_name_prefix="filterNamePrefix",
-    log_group_name="logGroupName",
-    metric_name="metricName",
-    metric_namespace="metricNamespace",
-):
-    return {
-        "name": name,
-        "input": build_describe_input(
-            filter_name_prefix, log_group_name, metric_name, metric_namespace
-        ),
-    }
-
-
-@mock_logs
+@mock_aws
 @pytest.mark.parametrize(
     "kms_key_id",
     [
@@ -453,7 +173,7 @@ def test_create_log_group(kms_key_id):
         assert log_group["kmsKeyId"] == kms_key_id
 
 
-@mock_logs
+@mock_aws
 def test_exceptions():
     conn = boto3.client("logs", TEST_REGION)
     log_group_name = "dummy"
@@ -485,7 +205,7 @@ def test_exceptions():
     assert error["Message"] == "The specified log stream does not exist."
 
 
-@mock_logs
+@mock_aws
 def test_put_logs():
     conn = boto3.client("logs", TEST_REGION)
     log_group_name = "dummy"
@@ -509,7 +229,7 @@ def test_put_logs():
     assert len(events) == 2
 
 
-@mock_logs
+@mock_aws
 def test_put_log_events_in_wrong_order():
     conn = boto3.client("logs", "us-east-1")
     log_group_name = "test"
@@ -540,7 +260,7 @@ def test_put_log_events_in_wrong_order():
     )
 
 
-@mock_logs
+@mock_aws
 @pytest.mark.parametrize("days_ago", [15, 400])
 def test_put_log_events_in_the_past(days_ago):
     conn = boto3.client("logs", "us-east-1")
@@ -559,7 +279,7 @@ def test_put_log_events_in_the_past(days_ago):
     assert resp["rejectedLogEventsInfo"] == {"tooOldLogEventEndIndex": 0}
 
 
-@mock_logs
+@mock_aws
 @pytest.mark.parametrize("minutes", [181, 300, 999999])
 def test_put_log_events_in_the_future(minutes):
     conn = boto3.client("logs", "us-east-1")
@@ -578,7 +298,7 @@ def test_put_log_events_in_the_future(minutes):
     assert resp["rejectedLogEventsInfo"] == {"tooNewLogEventStartIndex": 0}
 
 
-@mock_logs
+@mock_aws
 def test_put_retention_policy():
     conn = boto3.client("logs", TEST_REGION)
     log_group_name = "dummy"
@@ -593,7 +313,7 @@ def test_put_retention_policy():
     conn.delete_log_group(logGroupName=log_group_name)
 
 
-@mock_logs
+@mock_aws
 def test_delete_log_stream():
     logs = boto3.client("logs", TEST_REGION)
     logs.create_log_group(logGroupName="logGroup")
@@ -605,7 +325,7 @@ def test_delete_log_stream():
     assert resp["logStreams"] == []
 
 
-@mock_logs
+@mock_aws
 def test_delete_retention_policy():
     conn = boto3.client("logs", TEST_REGION)
     log_group_name = "dummy"
@@ -626,7 +346,7 @@ def test_delete_retention_policy():
     conn.delete_log_group(logGroupName=log_group_name)
 
 
-@mock_logs
+@mock_aws
 def test_put_resource_policy():
     client = boto3.client("logs", TEST_REGION)
 
@@ -672,7 +392,7 @@ def test_put_resource_policy():
         assert created_time < policy_info["lastUpdatedTime"] <= int(unix_time_millis())
 
 
-@mock_logs
+@mock_aws
 def test_put_resource_policy_too_many():
     client = boto3.client("logs", TEST_REGION)
 
@@ -700,7 +420,7 @@ def test_put_resource_policy_too_many():
     )
 
 
-@mock_logs
+@mock_aws
 def test_delete_resource_policy():
     client = boto3.client("logs", TEST_REGION)
 
@@ -733,7 +453,7 @@ def test_delete_resource_policy():
     )
 
 
-@mock_logs
+@mock_aws
 def test_describe_resource_policies():
     client = boto3.client("logs", TEST_REGION)
 
@@ -759,7 +479,7 @@ def test_describe_resource_policies():
         assert policy["lastUpdatedTime"] <= now_millis
 
 
-@mock_logs
+@mock_aws
 def test_get_log_events():
     client = boto3.client("logs", TEST_REGION)
     log_group_name = "test"
@@ -852,7 +572,83 @@ def test_get_log_events():
     )
 
 
-@mock_logs
+@pytest.mark.aws_verified
+@aws_verified
+def test_arn_formats_log_group_and_stream(account_id, log_group_name):
+    client = boto3.client("logs", TEST_REGION)
+
+    # Verify that we return all LogGroup ARN's
+    group = client.describe_log_groups(logGroupNamePrefix=log_group_name)["logGroups"][
+        0
+    ]
+    assert group["logGroupName"] == log_group_name
+    assert (
+        group["arn"]
+        == f"arn:aws:logs:{TEST_REGION}:{account_id}:log-group:{log_group_name}:*"
+    )
+    assert (
+        group["logGroupArn"]
+        == f"arn:aws:logs:{TEST_REGION}:{account_id}:log-group:{log_group_name}"
+    )
+
+    client.create_log_stream(logGroupName=log_group_name, logStreamName="stream")
+
+    # Verify that LogStreams have the correct ARN
+    stream = client.describe_log_streams(logGroupName=log_group_name)["logStreams"][0]
+    assert stream["logStreamName"] == "stream"
+    assert (
+        stream["arn"]
+        == f"arn:aws:logs:{TEST_REGION}:{account_id}:log-group:{log_group_name}:log-stream:stream"
+    )
+
+    # Verify that LogStreams can be found using the logStreamIdentifier
+    stream = client.describe_log_streams(logGroupIdentifier=group["logGroupArn"])[
+        "logStreams"
+    ][0]
+    assert stream["logStreamName"] == "stream"
+
+    # We can't use the ARN, as that throws a ValidationError
+    with pytest.raises(ClientError) as exc:
+        client.describe_log_streams(logGroupIdentifier=group["arn"])
+    err = exc.value.response["Error"]
+    assert err["Code"] == "InvalidParameterException"
+    assert (
+        err["Message"]
+        == f"1 validation error detected: Value '{group['arn']}' at 'logGroupIdentifier' failed to satisfy constraint: Member must satisfy regular expression pattern: [\\w#+=/:,.@-]*"
+    )
+
+
+@pytest.mark.aws_verified
+@aws_verified
+def test_get_log_events_using_arn(account_id, log_group_name):
+    client = boto3.client("logs", TEST_REGION)
+
+    group = client.describe_log_groups(logGroupNamePrefix=log_group_name)["logGroups"][
+        0
+    ]
+
+    client.create_log_stream(logGroupName=log_group_name, logStreamName="stream")
+
+    # Verify we can call this method with all variantions
+    # Note that we don't verify whether it returns anything - we just want to ensure that the parameters are valid
+    client.get_log_events(logGroupName=log_group_name, logStreamName="stream")
+    client.get_log_events(logGroupIdentifier=log_group_name, logStreamName="stream")
+    client.get_log_events(
+        logGroupIdentifier=group["logGroupArn"], logStreamName="stream"
+    )
+
+    # We can't use the ARN, as that throws a ValidationError
+    with pytest.raises(ClientError) as exc:
+        client.get_log_events(logGroupIdentifier=group["arn"], logStreamName="stream")
+    err = exc.value.response["Error"]
+    assert err["Code"] == "InvalidParameterException"
+    assert (
+        err["Message"]
+        == f"1 validation error detected: Value '{group['arn']}' at 'logGroupIdentifier' failed to satisfy constraint: Member must satisfy regular expression pattern: [\\w#+=/:,.@-]*"
+    )
+
+
+@mock_aws
 def test_get_log_events_with_start_from_head():
     client = boto3.client("logs", TEST_REGION)
     log_group_name = "test"
@@ -948,7 +744,7 @@ def test_get_log_events_with_start_from_head():
     )
 
 
-@mock_logs
+@mock_aws
 def test_get_log_events_errors():
     client = boto3.client("logs", TEST_REGION)
     log_group_name = "test"
@@ -985,7 +781,7 @@ def test_get_log_events_errors():
     )
 
 
-@mock_logs
+@mock_aws
 def test_list_tags_log_group():
     conn = boto3.client("logs", TEST_REGION)
     log_group_name = "dummy"
@@ -1003,7 +799,7 @@ def test_list_tags_log_group():
     conn.delete_log_group(logGroupName=log_group_name)
 
 
-@mock_logs
+@mock_aws
 def test_tag_log_group():
     conn = boto3.client("logs", TEST_REGION)
     log_group_name = "dummy"
@@ -1027,7 +823,7 @@ def test_tag_log_group():
     conn.delete_log_group(logGroupName=log_group_name)
 
 
-@mock_logs
+@mock_aws
 def test_untag_log_group():
     conn = boto3.client("logs", TEST_REGION)
     log_group_name = "dummy"
@@ -1047,7 +843,7 @@ def test_untag_log_group():
     conn.delete_log_group(logGroupName=log_group_name)
 
 
-@mock_logs
+@mock_aws
 def test_describe_subscription_filters():
     # given
     client = boto3.client("logs", "us-east-1")
@@ -1061,7 +857,7 @@ def test_describe_subscription_filters():
     assert len(response["subscriptionFilters"]) == 0
 
 
-@mock_logs
+@mock_aws
 def test_describe_subscription_filters_errors():
     # given
     client = boto3.client("logs", "us-east-1")
@@ -1081,7 +877,7 @@ def test_describe_subscription_filters_errors():
     )
 
 
-@mock_logs
+@mock_aws
 def test_describe_log_groups_paging():
     client = boto3.client("logs", "us-east-1")
 
@@ -1117,7 +913,7 @@ def test_describe_log_groups_paging():
     assert "nextToken" not in resp
 
 
-@mock_logs
+@mock_aws
 def test_describe_log_streams_simple_paging():
     client = boto3.client("logs", "us-east-1")
 
@@ -1169,7 +965,7 @@ def test_describe_log_streams_simple_paging():
     assert "nextToken" not in resp
 
 
-@mock_logs
+@mock_aws
 def test_describe_log_streams_paging():
     client = boto3.client("logs", "us-east-1")
 
@@ -1229,7 +1025,7 @@ def test_describe_log_streams_paging():
 
 
 @pytest.mark.parametrize("nr_of_events", [10001, 1000000])
-@mock_logs
+@mock_aws
 def test_get_too_many_log_events(nr_of_events):
     client = boto3.client("logs", "us-east-1")
     log_group_name = "dummy"
@@ -1254,7 +1050,7 @@ def test_get_too_many_log_events(nr_of_events):
 
 
 @pytest.mark.parametrize("nr_of_events", [10001, 1000000])
-@mock_logs
+@mock_aws
 def test_filter_too_many_log_events(nr_of_events):
     client = boto3.client("logs", "us-east-1")
     log_group_name = "dummy"
@@ -1279,7 +1075,7 @@ def test_filter_too_many_log_events(nr_of_events):
 
 
 @pytest.mark.parametrize("nr_of_groups", [51, 100])
-@mock_logs
+@mock_aws
 def test_describe_too_many_log_groups(nr_of_groups):
     client = boto3.client("logs", "us-east-1")
     with pytest.raises(ClientError) as ex:
@@ -1295,7 +1091,7 @@ def test_describe_too_many_log_groups(nr_of_groups):
 
 
 @pytest.mark.parametrize("nr_of_streams", [51, 100])
-@mock_logs
+@mock_aws
 def test_describe_too_many_log_streams(nr_of_streams):
     client = boto3.client("logs", "us-east-1")
     log_group_name = "dummy"
@@ -1313,7 +1109,7 @@ def test_describe_too_many_log_streams(nr_of_streams):
 
 
 @pytest.mark.parametrize("length", [513, 1000])
-@mock_logs
+@mock_aws
 def test_create_log_group_invalid_name_length(length):
     log_group_name = "a" * length
     client = boto3.client("logs", "us-east-1")
@@ -1330,7 +1126,7 @@ def test_create_log_group_invalid_name_length(length):
 
 
 @pytest.mark.parametrize("invalid_orderby", ["", "sth", "LogStreamname"])
-@mock_logs
+@mock_aws
 def test_describe_log_streams_invalid_order_by(invalid_orderby):
     client = boto3.client("logs", "us-east-1")
     log_group_name = "dummy"
@@ -1352,7 +1148,7 @@ def test_describe_log_streams_invalid_order_by(invalid_orderby):
     )
 
 
-@mock_logs
+@mock_aws
 def test_describe_log_streams_no_prefix():
     """
     From the docs: If orderBy is LastEventTime , you cannot specify [logStreamNamePrefix]
