@@ -2,11 +2,11 @@ import boto3
 import pytest
 from botocore.exceptions import ClientError
 
-from moto import mock_rds
+from moto import mock_aws
 
 
 class TestDBInstanceFilters:
-    mock = mock_rds()
+    mock = mock_aws()
 
     @classmethod
     def setup_class(cls):
@@ -55,7 +55,7 @@ class TestDBInstanceFilters:
 
         db_instances = self.client.describe_db_instances(
             Filters=[{"Name": "db-cluster-id", "Values": [db_cluster_identifier]}]
-        ).get("DBInstances")
+        )["DBInstances"]
         assert len(db_instances) == 1
         assert db_instances[0]["DBClusterIdentifier"] == db_cluster_identifier
 
@@ -65,7 +65,7 @@ class TestDBInstanceFilters:
 
         db_instances = self.client.describe_db_instances(
             Filters=[{"Name": "db-instance-id", "Values": [db_instance_identifier]}]
-        ).get("DBInstances")
+        )["DBInstances"]
         assert len(db_instances) == 1
         assert db_instances[0]["DBInstanceIdentifier"] == db_instance_identifier
 
@@ -75,7 +75,7 @@ class TestDBInstanceFilters:
 
         db_instances = self.client.describe_db_instances(
             Filters=[{"Name": "db-instance-id", "Values": [db_instance_arn]}]
-        ).get("DBInstances")
+        )["DBInstances"]
         assert len(db_instances) == 1
         assert db_instances[0]["DBInstanceArn"] == db_instance_arn
 
@@ -85,20 +85,20 @@ class TestDBInstanceFilters:
 
         db_instances = self.client.describe_db_instances(
             Filters=[{"Name": "dbi-resource-id", "Values": [dbi_resource_identifier]}]
-        ).get("DBInstances")
+        )["DBInstances"]
         for db_instance in db_instances:
             assert db_instance["DbiResourceId"] == dbi_resource_identifier
 
     def test_engine_filter(self):
         db_instances = self.client.describe_db_instances(
             Filters=[{"Name": "engine", "Values": ["postgres"]}]
-        ).get("DBInstances")
+        )["DBInstances"]
         for db_instance in db_instances:
             assert db_instance["Engine"] == "postgres"
 
         db_instances = self.client.describe_db_instances(
             Filters=[{"Name": "engine", "Values": ["oracle"]}]
-        ).get("DBInstances")
+        )["DBInstances"]
         assert len(db_instances) == 0
 
     def test_multiple_filters(self):
@@ -188,7 +188,7 @@ class TestDBInstanceFilters:
 
 
 class TestDBSnapshotFilters:
-    mock = mock_rds()
+    mock = mock_aws()
 
     @classmethod
     def setup_class(cls):
@@ -239,7 +239,7 @@ class TestDBSnapshotFilters:
     def test_db_snapshot_id_filter(self):
         snapshots = self.client.describe_db_snapshots(
             Filters=[{"Name": "db-snapshot-id", "Values": ["db-instance-1-snapshot-0"]}]
-        ).get("DBSnapshots")
+        )["DBSnapshots"]
         assert len(snapshots) == 1
         assert snapshots[0]["DBSnapshotIdentifier"] == "db-instance-1-snapshot-0"
 
@@ -249,7 +249,7 @@ class TestDBSnapshotFilters:
 
         snapshots = self.client.describe_db_snapshots(
             Filters=[{"Name": "db-instance-id", "Values": [db_instance_identifier]}]
-        ).get("DBSnapshots")
+        )["DBSnapshots"]
         for snapshot in snapshots:
             assert snapshot["DBInstanceIdentifier"] == db_instance_identifier
 
@@ -260,7 +260,7 @@ class TestDBSnapshotFilters:
 
         snapshots = self.client.describe_db_snapshots(
             Filters=[{"Name": "db-instance-id", "Values": [db_instance_arn]}]
-        ).get("DBSnapshots")
+        )["DBSnapshots"]
         for snapshot in snapshots:
             assert snapshot["DBInstanceIdentifier"] == db_instance_identifier
 
@@ -270,20 +270,20 @@ class TestDBSnapshotFilters:
 
         snapshots = self.client.describe_db_snapshots(
             Filters=[{"Name": "dbi-resource-id", "Values": [dbi_resource_identifier]}]
-        ).get("DBSnapshots")
+        )["DBSnapshots"]
         for snapshot in snapshots:
             assert snapshot["DbiResourceId"] == dbi_resource_identifier
 
     def test_engine_filter(self):
         snapshots = self.client.describe_db_snapshots(
             Filters=[{"Name": "engine", "Values": ["postgres"]}]
-        ).get("DBSnapshots")
+        )["DBSnapshots"]
         for snapshot in snapshots:
             assert snapshot["Engine"] == "postgres"
 
         snapshots = self.client.describe_db_snapshots(
             Filters=[{"Name": "engine", "Values": ["oracle"]}]
-        ).get("DBSnapshots")
+        )["DBSnapshots"]
         assert len(snapshots) == 0
 
     def test_snapshot_type_filter(self):
@@ -308,7 +308,7 @@ class TestDBSnapshotFilters:
                 },
                 {"Name": "engine", "Values": ["mysql"]},
             ]
-        ).get("DBSnapshots")
+        )["DBSnapshots"]
         assert len(snapshots) == 1
         assert snapshots[0]["DBSnapshotIdentifier"] == "db-instance-0-snapshot-1"
 
@@ -364,7 +364,7 @@ class TestDBSnapshotFilters:
                 },
                 {"Name": "engine", "Values": ["mysql", "postgres"]},
             ],
-        ).get("DBSnapshots")
+        )["DBSnapshots"]
         returned_identifiers = [ss["DBSnapshotIdentifier"] for ss in snapshots]
         assert len(returned_identifiers) == 2
         assert "db-instance-0-snapshot-0" in returned_identifiers
@@ -385,7 +385,7 @@ class TestDBSnapshotFilters:
 
 
 class TestDBClusterSnapshotFilters:
-    mock = mock_rds()
+    mock = mock_aws()
 
     @classmethod
     def setup_class(cls):
