@@ -4,14 +4,13 @@ from email.mime.text import MIMEText
 
 import boto3
 import pytest
-from botocore.exceptions import ClientError, ParamValidationError
+from botocore.exceptions import ClientError
 
-from moto import mock_ses
-
-from . import ses_aws_verified
+from moto import mock_aws
+from tests import aws_verified
 
 
-@mock_ses
+@mock_aws
 def test_list_verified_identities():
     conn = boto3.client("ses", region_name="us-east-1")
     conn.verify_email_identity(EmailAddress="test@example.com")
@@ -40,7 +39,7 @@ def test_list_verified_identities():
     )
 
 
-@mock_ses
+@mock_aws
 def test_identities_are_region_specific():
     us_east = boto3.client("ses", region_name="us-east-1")
     us_east.verify_email_identity(EmailAddress="test@example.com")
@@ -49,7 +48,7 @@ def test_identities_are_region_specific():
     assert not us_west.list_identities()["Identities"]
 
 
-@mock_ses
+@mock_aws
 def test_verify_email_identity_idempotency():
     conn = boto3.client("ses", region_name="us-east-1")
     address = "test@example.com"
@@ -61,7 +60,7 @@ def test_verify_email_identity_idempotency():
     assert address_list == [address]
 
 
-@mock_ses
+@mock_aws
 def test_verify_email_address():
     conn = boto3.client("ses", region_name="us-east-1")
     conn.verify_email_address(EmailAddress="test@example.com")
@@ -70,7 +69,7 @@ def test_verify_email_address():
     assert email == "test@example.com"
 
 
-@mock_ses
+@mock_aws
 def test_delete_identity():
     conn = boto3.client("ses", region_name="us-east-1")
     conn.verify_email_identity(EmailAddress="test@example.com")
@@ -80,7 +79,7 @@ def test_delete_identity():
     assert not conn.list_identities()["Identities"]
 
 
-@mock_ses
+@mock_aws
 def test_send_email():
     conn = boto3.client("ses", region_name="us-east-1")
 
@@ -112,7 +111,7 @@ def test_send_email():
     assert sent_count == 3
 
 
-@mock_ses
+@mock_aws
 def test_send_email_when_verify_source():
     conn = boto3.client("ses", region_name="us-east-1")
 
@@ -141,7 +140,7 @@ def test_send_email_when_verify_source():
     assert sent_count == 2
 
 
-@mock_ses
+@mock_aws
 def test_send_unverified_email_with_chevrons():
     conn = boto3.client("ses", region_name="us-east-1")
 
@@ -167,7 +166,7 @@ def test_send_unverified_email_with_chevrons():
     )
 
 
-@mock_ses
+@mock_aws
 def test_send_email_invalid_address():
     conn = boto3.client("ses", region_name="us-east-1")
     conn.verify_domain_identity(Domain="example.com")
@@ -190,7 +189,7 @@ def test_send_email_invalid_address():
     assert err["Message"] == "Missing domain"
 
 
-@mock_ses
+@mock_aws
 def test_send_bulk_templated_email():
     conn = boto3.client("ses", region_name="us-east-1")
 
@@ -286,7 +285,7 @@ def test_send_bulk_templated_email():
     assert sent_count == 6
 
 
-@mock_ses
+@mock_aws
 def test_send_templated_email():
     conn = boto3.client("ses", region_name="us-east-1")
 
@@ -333,7 +332,7 @@ def test_send_templated_email():
     assert sent_count == 3
 
 
-@mock_ses
+@mock_aws
 def test_send_templated_email_invalid_address():
     conn = boto3.client("ses", region_name="us-east-1")
     conn.verify_domain_identity(Domain="example.com")
@@ -362,7 +361,7 @@ def test_send_templated_email_invalid_address():
     assert err["Message"] == "Missing domain"
 
 
-@mock_ses
+@mock_aws
 def test_send_html_email():
     conn = boto3.client("ses", region_name="us-east-1")
 
@@ -386,7 +385,7 @@ def test_send_html_email():
     assert sent_count == 1
 
 
-@mock_ses
+@mock_aws
 def test_send_raw_email():
     conn = boto3.client("ses", region_name="us-east-1")
 
@@ -405,7 +404,7 @@ def test_send_raw_email():
     assert sent_count == 2
 
 
-@mock_ses
+@mock_aws
 def test_send_raw_email_validate_domain():
     conn = boto3.client("ses", region_name="us-east-1")
 
@@ -424,7 +423,7 @@ def test_send_raw_email_validate_domain():
     assert sent_count == 2
 
 
-@mock_ses
+@mock_aws
 def test_send_raw_email_invalid_address():
     conn = boto3.client("ses", region_name="us-east-1")
     conn.verify_domain_identity(Domain="example.com")
@@ -458,7 +457,7 @@ def get_raw_email():
     return message
 
 
-@mock_ses
+@mock_aws
 def test_send_raw_email_without_source():
     conn = boto3.client("ses", region_name="us-east-1")
 
@@ -489,7 +488,7 @@ def test_send_raw_email_without_source():
     assert sent_count == 2
 
 
-@mock_ses
+@mock_aws
 def test_send_raw_email_without_source_or_from():
     conn = boto3.client("ses", region_name="us-east-1")
 
@@ -511,7 +510,7 @@ def test_send_raw_email_without_source_or_from():
         conn.send_raw_email(**kwargs)
 
 
-@mock_ses
+@mock_aws
 def test_send_email_notification_with_encoded_sender():
     sender = "Foo <foo@bar.baz>"
     conn = boto3.client("ses", region_name="us-east-1")
@@ -524,7 +523,7 @@ def test_send_email_notification_with_encoded_sender():
     assert response["ResponseMetadata"]["HTTPStatusCode"] == 200
 
 
-@mock_ses
+@mock_aws
 def test_create_configuration_set():
     conn = boto3.client("ses", region_name="us-east-1")
     conn.create_configuration_set(ConfigurationSet=dict({"Name": "test"}))
@@ -576,7 +575,7 @@ def test_create_configuration_set():
     assert ex.value.response["Error"]["Code"] == "EventDestinationAlreadyExists"
 
 
-@mock_ses
+@mock_aws
 def test_describe_configuration_set():
     conn = boto3.client("ses", region_name="us-east-1")
 
@@ -595,7 +594,39 @@ def test_describe_configuration_set():
     assert config_set["ConfigurationSet"]["Name"] == name
 
 
-@mock_ses
+@mock_aws
+def test_list_configuration_sets():
+    conn = boto3.client("ses", region_name="us-east-1")
+    conn.create_configuration_set(ConfigurationSet=dict({"Name": "test1"}))
+    conn.create_configuration_set(ConfigurationSet=dict({"Name": "test2"}))
+    conn.create_configuration_set(ConfigurationSet=dict({"Name": "test3"}))
+
+    config_sets = conn.list_configuration_sets()["ConfigurationSets"]
+    assert len(config_sets) == 3
+    config_set_names = [config_set["Name"] for config_set in config_sets]
+    assert "test1" in config_set_names
+    assert "test2" in config_set_names
+    assert "test3" in config_set_names
+
+
+@mock_aws
+def test_delete_configuration_set():
+    conn = boto3.client("ses", region_name="us-east-1")
+    conn.create_configuration_set(ConfigurationSet=dict({"Name": "test1"}))
+    conn.create_configuration_set(ConfigurationSet=dict({"Name": "test2"}))
+    conn.create_configuration_set(ConfigurationSet=dict({"Name": "test3"}))
+
+    config_sets = conn.list_configuration_sets()["ConfigurationSets"]
+    assert len(config_sets) == 3
+
+    conn.delete_configuration_set(ConfigurationSetName="test3")
+    config_sets = conn.list_configuration_sets()["ConfigurationSets"]
+    assert len(config_sets) == 2
+    config_set_names = [config_set["Name"] for config_set in config_sets]
+    assert "test3" not in config_set_names
+
+
+@mock_aws
 def test_create_receipt_rule_set():
     conn = boto3.client("ses", region_name="us-east-1")
     result = conn.create_receipt_rule_set(RuleSetName="testRuleSet")
@@ -608,7 +639,7 @@ def test_create_receipt_rule_set():
     assert ex.value.response["Error"]["Code"] == "RuleSetNameAlreadyExists"
 
 
-@mock_ses
+@mock_aws
 def test_create_receipt_rule():
     conn = boto3.client("ses", region_name="us-east-1")
     rule_set_name = "testRuleSet"
@@ -707,7 +738,7 @@ def test_create_receipt_rule():
     assert ex.value.response["Error"]["Code"] == "RuleSetDoesNotExist"
 
 
-@mock_ses
+@mock_aws
 def test_describe_receipt_rule_set():
     conn = boto3.client("ses", region_name="us-east-1")
     create_receipt_rule_set_response = conn.create_receipt_rule_set(
@@ -724,7 +755,7 @@ def test_describe_receipt_rule_set():
     assert not result["Rules"]
 
 
-@mock_ses
+@mock_aws
 def test_describe_receipt_rule_set_with_rules():
     conn = boto3.client("ses", region_name="us-east-1")
     create_receipt_rule_set_response = conn.create_receipt_rule_set(
@@ -773,7 +804,7 @@ def test_describe_receipt_rule_set_with_rules():
     assert result["Rules"][0] == receipt_rule
 
 
-@mock_ses
+@mock_aws
 def test_describe_receipt_rule():
     conn = boto3.client("ses", region_name="us-east-1")
     rule_set_name = "testRuleSet"
@@ -875,7 +906,7 @@ def test_describe_receipt_rule():
     assert error.value.response["Error"]["Code"] == "RuleDoesNotExist"
 
 
-@mock_ses
+@mock_aws
 def test_update_receipt_rule():
     conn = boto3.client("ses", region_name="us-east-1")
     rule_set_name = "testRuleSet"
@@ -1021,40 +1052,8 @@ def test_update_receipt_rule():
         "Rule does not exist: invalidRuleName"
     )
 
-    with pytest.raises(ParamValidationError) as error:
-        conn.update_receipt_rule(
-            RuleSetName=rule_set_name,
-            Rule={
-                "Enabled": True,
-                "TlsPolicy": "Optional",
-                "Recipients": ["test@email.com"],
-                "Actions": [
-                    {
-                        "S3Action": {
-                            "TopicArn": "string",
-                            "BucketName": "testBucketName",
-                            "ObjectKeyPrefix": "testObjectKeyPrefix",
-                            "KmsKeyArn": "string",
-                        },
-                        "BounceAction": {
-                            "TopicArn": "string",
-                            "SmtpReplyCode": "string",
-                            "StatusCode": "string",
-                            "Message": "string",
-                            "Sender": "string",
-                        },
-                    }
-                ],
-                "ScanEnabled": False,
-            },
-        )
 
-    assert (
-        'Parameter validation failed:\nMissing required parameter in Rule: "Name"'
-    ) in str(error.value)
-
-
-@mock_ses
+@mock_aws
 def test_update_receipt_rule_actions():
     conn = boto3.client("ses", region_name="us-east-1")
     rule_set_name = "testRuleSet"
@@ -1127,11 +1126,13 @@ def test_update_receipt_rule_actions():
     assert "S3Action" in updated_rule_description["Rule"]["Actions"][0]
 
     assert (
-        updated_rule_description["Rule"]["Actions"][0]["S3Action"]["TopicArn"]
-    ) == "newString"
+        (updated_rule_description["Rule"]["Actions"][0]["S3Action"]["TopicArn"])
+        == "newString"
+    )
     assert (
-        updated_rule_description["Rule"]["Actions"][0]["S3Action"]["BucketName"]
-    ) == "updatedTestBucketName"
+        (updated_rule_description["Rule"]["Actions"][0]["S3Action"]["BucketName"])
+        == "updatedTestBucketName"
+    )
     assert updated_rule_description["Rule"]["Actions"][0]["S3Action"][
         "ObjectKeyPrefix"
     ] == ("updatedTestObjectKeyPrefix")
@@ -1147,11 +1148,17 @@ def test_update_receipt_rule_actions():
         == "newString"
     )
     assert (
-        updated_rule_description["Rule"]["Actions"][0]["BounceAction"]["SmtpReplyCode"]
-    ) == "newString"
+        (
+            updated_rule_description["Rule"]["Actions"][0]["BounceAction"][
+                "SmtpReplyCode"
+            ]
+        )
+        == "newString"
+    )
     assert (
-        updated_rule_description["Rule"]["Actions"][0]["BounceAction"]["StatusCode"]
-    ) == "newString"
+        (updated_rule_description["Rule"]["Actions"][0]["BounceAction"]["StatusCode"])
+        == "newString"
+    )
     assert (
         updated_rule_description["Rule"]["Actions"][0]["BounceAction"]["Message"]
         == "newString"
@@ -1161,41 +1168,8 @@ def test_update_receipt_rule_actions():
         == "newString"
     )
 
-    with pytest.raises(ParamValidationError) as error:
-        conn.update_receipt_rule(
-            RuleSetName=rule_set_name,
-            Rule={
-                "Name": rule_name,
-                "Enabled": False,
-                "TlsPolicy": "Optional",
-                "Recipients": ["test@email.com", "test2@email.com"],
-                "Actions": [
-                    {
-                        "S3Action": {
-                            "TopicArn": "newString",
-                            "ObjectKeyPrefix": "updatedTestObjectKeyPrefix",
-                            "KmsKeyArn": "newString",
-                        },
-                        "BounceAction": {
-                            "TopicArn": "newString",
-                            "StatusCode": "newString",
-                        },
-                    }
-                ],
-                "ScanEnabled": False,
-            },
-        )
 
-    assert (
-        "Parameter validation failed:\n"
-        'Missing required parameter in Rule.Actions[0].S3Action: "BucketName"\n'
-        'Missing required parameter in Rule.Actions[0].BounceAction: "SmtpReplyCode"\n'
-        'Missing required parameter in Rule.Actions[0].BounceAction: "Message"\n'
-        'Missing required parameter in Rule.Actions[0].BounceAction: "Sender"'
-    ) in str(error.value)
-
-
-@mock_ses
+@mock_aws
 def test_create_ses_template():
     conn = boto3.client("ses", region_name="us-east-1")
 
@@ -1228,7 +1202,7 @@ def test_create_ses_template():
     assert result["Template"]["TemplateName"] == "MyTemplate"
     assert result["Template"]["SubjectPart"] == "Greetings, {{name}}!"
     assert result["Template"]["HtmlPart"] == (
-        "<h1>Hello {{name}}," "</h1><p>Your favorite animal is {{favoriteanimal}}.</p>"
+        "<h1>Hello {{name}},</h1><p>Your favorite animal is {{favoriteanimal}}.</p>"
     )
     # get a template which is not present
     with pytest.raises(ClientError) as ex:
@@ -1240,7 +1214,7 @@ def test_create_ses_template():
     assert result["TemplatesMetadata"][0]["Name"] == "MyTemplate"
 
 
-@mock_ses
+@mock_aws
 def test_render_template():
     conn = boto3.client("ses", region_name="us-east-1")
 
@@ -1306,7 +1280,7 @@ def test_render_template():
 
 
 @pytest.mark.aws_verified
-@ses_aws_verified
+@aws_verified
 def test_render_template__advanced():
     conn = boto3.client("ses", region_name="us-east-1")
 
@@ -1338,7 +1312,7 @@ def test_render_template__advanced():
         conn.delete_template(TemplateName="MTT")
 
 
-@mock_ses
+@mock_aws
 def test_update_ses_template():
     conn = boto3.client("ses", region_name="us-east-1")
     template = {
@@ -1357,9 +1331,9 @@ def test_update_ses_template():
 
     template["SubjectPart"] = "Hi, {{name}}!"
     template["TextPart"] = "Dear {{name}},\r\n Your favorite color is {{color}}"
-    template[
-        "HtmlPart"
-    ] = "<h1>Hello {{name}},</h1><p>Your favorite color is {{color}}</p>"
+    template["HtmlPart"] = (
+        "<h1>Hello {{name}},</h1><p>Your favorite color is {{color}}</p>"
+    )
     conn.update_template(Template=template)
 
     result = conn.get_template(TemplateName=template["TemplateName"])
@@ -1372,7 +1346,7 @@ def test_update_ses_template():
     )
 
 
-@mock_ses
+@mock_aws
 def test_domains_are_case_insensitive():
     client = boto3.client("ses", region_name="us-east-1")
     duplicate_domains = [
@@ -1388,7 +1362,7 @@ def test_domains_are_case_insensitive():
         assert identities[0] == "example.com"
 
 
-@mock_ses
+@mock_aws
 def test_get_send_statistics():
     conn = boto3.client("ses", region_name="us-east-1")
 
@@ -1429,7 +1403,7 @@ def test_get_send_statistics():
     assert stats[0]["DeliveryAttempts"] == 1
 
 
-@mock_ses
+@mock_aws
 def test_set_identity_mail_from_domain():
     conn = boto3.client("ses", region_name="eu-central-1")
 
@@ -1511,7 +1485,7 @@ def test_set_identity_mail_from_domain():
     assert "MailFromDomainStatus" not in actual_attributes
 
 
-@mock_ses
+@mock_aws
 def test_get_identity_mail_from_domain_attributes():
     conn = boto3.client("ses", region_name="eu-central-1")
 
@@ -1529,8 +1503,9 @@ def test_get_identity_mail_from_domain_attributes():
     assert len(attributes["MailFromDomainAttributes"]) == 1
     assert len(attributes["MailFromDomainAttributes"]["bar@foo.com"]) == 1
     assert (
-        attributes["MailFromDomainAttributes"]["bar@foo.com"]["BehaviorOnMXFailure"]
-    ) == "UseDefaultValue"
+        (attributes["MailFromDomainAttributes"]["bar@foo.com"]["BehaviorOnMXFailure"])
+        == "UseDefaultValue"
+    )
 
     # Must return multiple configured identities
     conn.verify_domain_identity(Domain="lorem.com")
@@ -1542,7 +1517,7 @@ def test_get_identity_mail_from_domain_attributes():
     assert len(attributes["MailFromDomainAttributes"]["lorem.com"]) == 1
 
 
-@mock_ses
+@mock_aws
 def test_get_identity_verification_attributes():
     conn = boto3.client("ses", region_name="eu-central-1")
 
